@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # ------------------------------------
-# Authors:    Luis Miguel Sanchez Brea and Jesus del Hoyo
+# Authors:    Jesus del Hoyo and Luis Miguel Sanchez Brea
 # Date:       2019/02/03 (version 1.0)
 # License:    GPL
 # ------------------------------------
@@ -26,13 +26,14 @@ from .utils import nearest2
 Axes3D = Axes3D  # pycharm auto import
 colors = matplotlib.colors.TABLEAU_COLORS
 name_colors = list(colors)
-linestyles = [('dashdot', 'dashdot'),
-              ('loosely dashdotted', (0, (3, 10, 1, 10))),
-              ('dashdotted', (0, (3, 5, 1, 5))),
-              ('densely dashdotted', (0, (3, 1, 1, 1))),
-              ('dashdotdotted', (0, (3, 5, 1, 5, 1, 5))),
-              ('loosely dashdotdotted', (0, (3, 10, 1, 10, 1, 10))),
-              ('densely dashdotdotted', (0, (3, 1, 1, 1, 1, 1)))]
+# linestyles = [('dashdot', 'dashdot'),
+#               ('loosely dashdotted', (0, (3, 10, 1, 10))),
+#               ('dashdotted', (0, (3, 5, 1, 5))),
+#               ('densely dashdotted', (0, (3, 1, 1, 1))),
+#               ('dashdotdotted', (0, (3, 5, 1, 5, 1, 5))),
+#               ('loosely dashdotdotted', (0, (3, 10, 1, 10, 1, 10))),
+#               ('densely dashdotdotted', (0, (3, 1, 1, 1, 1, 1)))]
+linestyles = ['dotted', 'dashed', 'dashdot', 'loosely dotted', 'loosely dashed', 'loosely dashdot']
 
 # def draw2D(image, x, y, color="hot"):  # YlGnBu  RdBu, jet, hot
 #     """Draws a 2D image.
@@ -176,9 +177,7 @@ def draw_empty_sphere(ax, angle_view, axis_equal=True):
         try:
             ax.set_aspect('equal')
         except:
-            print(
-                'Axis equal not supported by your current version of Matplotlib'
-            )
+            pass
 
 
 def draw_poincare(S,
@@ -199,7 +198,7 @@ def draw_poincare(S,
         stokes_points (Stokes, list, None): list of Stokes points.
         angle_view (float, float): Elevation and azimuth for viewing.
         is_normalized (bool): normalize intensity to 1.
-        kind (str): 'line' or 'scatter'.
+        kind (str): 'line', 'scatter' or 'both'.
         color (str): color of line or scatter.
         label (str): labels for drawing.
         filename (str): name of filename to save the figure.
@@ -577,7 +576,7 @@ def draw_ellipse(E,
         if len(contour_levels) <= len(linestyles):
             line_styles = linestyles[:len(contour_levels)]
         else:
-            line_styles = linestyles[0]
+            line_styles = [linestyles[0]]
 
     # Main loop
     ax = []
@@ -652,8 +651,8 @@ def draw_ellipse(E,
                 contour_levels,
                 colors=(color),
                 linewidths=1.5,
-                # linestyles=line_styles)
-                linestyles=('dashdot'))
+                linestyles=line_styles)
+                # linestyles=('dashdot'))
         # Additions to figure
         if indC == Ncurves - 1:
             plt.axis('equal')
@@ -661,8 +660,8 @@ def draw_ellipse(E,
             plt.grid(True)
             axis.set_xlim(-limit, limit)
             axis.set_ylim(-limit, limit)
-            axis.set_xlabel('$E_x (V/m)$', fontsize=14)
-            axis.set_ylabel('$E_y (V/m)$', fontsize=14)
+            axis.set_xlabel('$E_x$', fontsize=14)
+            axis.set_ylabel('$E_y$', fontsize=14)
             plt.tight_layout()
             if Ncurves > 1:
                 plt.legend()
