@@ -211,10 +211,8 @@ def reshape(vars, shape_like=None, shape_fun=None, shape=None, obj=None):
     # Check how many variables we have
     N = len(vars)
     # Select the correct shape
-    shape, _ = select_shape(shape_var=shape,
-                            shape_fun=shape_fun,
-                            shape_like=shape_like,
-                            obj=obj)
+    shape, _ = select_shape(
+        shape_var=shape, shape_fun=shape_fun, shape_like=shape_like, obj=obj)
     # Act only if there is a shape
     if shape is not None:
         for ind, elem in enumerate(vars):
@@ -268,6 +266,7 @@ def select_shape(obj=None, shape_var=None, shape_fun=None, shape_like=None):
         else:
             shape = [obj.size]
             shapes = [shape_like, shape_fun, shape_var, obj.shape]
+            # print(obj.shape)
             for s in shapes:
                 if s is not None:
                     # If shape is False, force a None shape
@@ -733,22 +732,19 @@ def prepare_variables_blocks(M00=None,
                 shape4 = np.delete(shape4, ind2)
                 ind2 = ind2 + 1
                 # Calculate the components and construct the matrix from them
-                m = np.array(
-                    [[
-                        cte * multitake(m, [0, 0], [ind1, ind2]).flatten(),
-                        cte * multitake(m, [0, 1], [ind1, ind2]).flatten(),
-                        cte * multitake(m, [0, 2], [ind1, ind2]).flatten()
-                    ],
-                     [
-                         cte * multitake(m, [1, 0], [ind1, ind2]).flatten(),
-                         cte * multitake(m, [1, 1], [ind1, ind2]).flatten(),
-                         cte * multitake(m, [1, 2], [ind1, ind2]).flatten()
-                     ],
-                     [
-                         cte * multitake(m, [2, 0], [ind1, ind2]).flatten(),
-                         cte * multitake(m, [2, 1], [ind1, ind2]).flatten(),
-                         cte * multitake(m, [2, 2], [ind1, ind2]).flatten()
-                     ]])
+                m = np.array([[
+                    cte * multitake(m, [0, 0], [ind1, ind2]).flatten(),
+                    cte * multitake(m, [0, 1], [ind1, ind2]).flatten(),
+                    cte * multitake(m, [0, 2], [ind1, ind2]).flatten()
+                ], [
+                    cte * multitake(m, [1, 0], [ind1, ind2]).flatten(),
+                    cte * multitake(m, [1, 1], [ind1, ind2]).flatten(),
+                    cte * multitake(m, [1, 2], [ind1, ind2]).flatten()
+                ], [
+                    cte * multitake(m, [2, 0], [ind1, ind2]).flatten(),
+                    cte * multitake(m, [2, 1], [ind1, ind2]).flatten(),
+                    cte * multitake(m, [2, 2], [ind1, ind2]).flatten()
+                ]])
 
             else:
                 raise ValueError(
@@ -850,9 +846,10 @@ def rotation_matrix_Mueller(angle=0):
     # Definicion de la matrix
     c2b, s2b = (cos(2 * angle), sin(2 * angle))
     zero, one = (np.zeros_like(c2b), np.ones_like(c2b))
-    M = np.array([[one, zero, zero, zero], [zero, c2b, s2b, zero],
-                  [zero, -s2b, c2b, zero], [zero, zero, zero, one]],
-                 dtype=float)
+    M = np.array(
+        [[one, zero, zero, zero], [zero, c2b, s2b, zero],
+         [zero, -s2b, c2b, zero], [zero, zero, zero, one]],
+        dtype=float)
     return M
 
 
@@ -880,10 +877,8 @@ def azimuth_elipt_2_charac_angles(azimuth, ellipticity, out_number=True):
         delta (float) [0, 2*pi]: phase difference between both components of the eigenstates in Jones formalism.
     """
     # Prepare variables
-    (azimuth,
-     ellipticity), shape = prepare_variables(vars=[azimuth, ellipticity],
-                                             expand=[True, True],
-                                             give_shape=True)
+    (azimuth, ellipticity), shape = prepare_variables(
+        vars=[azimuth, ellipticity], expand=[True, True], give_shape=True)
     # Check that the angles belong to the correct interval. If not, fix it.
     azimuth = put_in_limits(azimuth, "azimuth", out_number=False)
     ellipticity = put_in_limits(ellipticity, "ellipticity", out_number=False)
@@ -956,9 +951,8 @@ def charac_angles_2_azimuth_elipt(alpha, delta):
         ellipticity (float) [-pi/4,np.pi/4]: Elipticity angle.
     """
     # Prepare variables
-    (alpha, delta), shape = prepare_variables(vars=[alpha, delta],
-                                              expand=[True, True],
-                                              give_shape=True)
+    (alpha, delta), shape = prepare_variables(
+        vars=[alpha, delta], expand=[True, True], give_shape=True)
     # Check that the angles belong to the correct interval. If not, fix it.
     alpha = put_in_limits(alpha, "alpha", out_number=False)
     delta = put_in_limits(delta, "delta", out_number=False)
@@ -988,8 +982,8 @@ def charac_angles_2_azimuth_elipt(alpha, delta):
     cond2 = (Mdelta == 0) + (Qalpha == 2.5)
     azimuth[cond1 * cond2] = azimuth[cond1 * cond2] + np.pi
     cond2 = np.logical_not(cond2)
-    cond3 = ((Mdelta == 1.5) + (Mdelta == 2.5) +
-             (Mdelta == 3.5)) * ((Qalpha == 1.5) + (Qalpha == 2.5))
+    cond3 = ((Mdelta == 1.5) + (Mdelta == 2.5) + (Mdelta == 3.5)) * (
+        (Qalpha == 1.5) + (Qalpha == 2.5))
     azimuth[cond1 * cond2 * cond3] = azimuth[cond1 * cond2 * cond3] + np.pi
     cond = (Qalpha == 1.5) * (Mdelta == 1.5)
     ellipticity[cond] = np.pi / 4
@@ -1096,9 +1090,8 @@ def extract_charac_angles(vector, use_nan=True, type='diattenuator'):
         delay (float) [0, 2*pi]: phase difference between both components of the eigenstates in Jones formalism.
     """
     # Do it with azimuth and ellipticity and convert
-    azimuth, ellipticity = extract_azimuth_elipt(vector=vector,
-                                                 use_nan=use_nan,
-                                                 type=type)
+    azimuth, ellipticity = extract_azimuth_elipt(
+        vector=vector, use_nan=use_nan, type=type)
     alpha, delay = azimuth_elipt_2_charac_angles(azimuth, ellipticity)
     return alpha, delay
 
@@ -1814,6 +1807,7 @@ def fit_cos(par, x, y):
 def fit_sine(t, data, has_draw=True):
     """fit a sine function
     """
+
     def optimize_func(x):
         return x[0] * np.sin(x[1] * t + x[2]) + x[3] - data
 
